%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dafxtests.m                 
%                                      
% Brian Hamilton, 2014                 
%                                      
% This script runs the experiments conducted in the DAFx'14 paper:
%
% "Finite volume perspectives on finite difference 
% schemes and boundary formulations for wave simulation"
%
% Parameters are set for each test and the script dafx2d.m is run.
%
% These tests (not optimised for speed) take about 90 seconds in total with 
% an Intel i5-2520M CPU @ 2.50GHz and 4GB of RAM using MATLAB 2012a
%
% These scripts can also be run in GNU Octave, although runtimes may vary.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tic
% FD 'centered' edge/corner updates + usual re-entrant corner update
gamma = 0;     % lossless walls
domain= 'A';
N     = 8e3;   % duration in time-steps
stype  = 'FDc' % FD 'centered' boundaries
run dafx2d

% domain B (stable)
domain= 'B';
N     = 8e3;   
%N     = 3e5;   % 300k time-steps to check longer time, quite slow   
stype  = 'FDc'
run dafx2d 

% check problematic domain with other scheme/boundaries
domain= 'A';
N     = 500;
% FD 'centered' edge/corner updates + three-quarter cell re-entrant corner update
stype  = 'FDc3q'
run dafx2d

%FD 'non-centered' boundaries
stype  = 'FDnc'
run dafx2d

% Digital waveguide mesh boundaries
stype  = 'DWM' 
run dafx2d

% this test verifies the relationship between gamma and gamma' in the DWM for
% the rectilinear DWM on an L-shaped geometry
stype  = 'DWM'  
gamma = 0.1;   % wall losses
domain= 'B';
run dafx2d

toc
